# Perforce Helix Installer ("HI")

## Welcome 

Welcome to the home of the Perforce Helix Installer project.

Perforce [Helix](http://www.perforce.com/helix) is a unified platform for collaborative development, version management, and protection of intellectual property.  It consists of an integrated ecosystem of proven, enterprise-grade systems for versioning, collaboration and code review, continuous integration and delivery, and other aspects of a DevOps pipeline.

Th Helix Installer is capable of quickly transforming a vanilla Linux machine -- virtual, bare metal, Docker container, etc. -- into a near-enterprise-grade deployment of several Helix Server components typically be present in a true enterprise installation.  The installation uses the [Server Deployment Package (SDP)](https://swarm.workshop.perforce.com/projects/perforce-software-sdp).

The installation is suitable for:

* Test suites for Helix server trigger and broker filter scripts deployed in enterprise environments.  For example, the [CBD](https://swarm.workshop.perforce.com/projects/perforce-software-cbd) test suite uses the Helix Installer to quickly spin up a test environment for server and triggers
* Demonstration
* Training
* Evaluation and Pilot projects.  Because the Helix Installer uses the SDP, translation from the demo-grade installation of the Helix Installer to an enterprise-grade installation is straightforward.

The Helix Installer is alternative to the [Helix Enterprise Evaluation virtual appliance (OVA)](http://www.perforce.com/downloads/helix).

Features
---
* Fast.  Runs in under 20 minutes, including download time and building required dependencies.
* Easy.  Provides reasonable defaults for port numbers, passwords, data storage areas, and all inputs that would otherwise require human interaction.
* Comprehensive.  Installs P4D and P4Broker, SDP, and a complete development pre-configured environment include Perl, P4Perl, Python, and P4Python, with appropriate shell environment settings to use them all immediately.  And more to come --  future versions will include Swarm, Git Fusion, and GitSwarm.
* Automates connection to the [Perforce Package Repository](http://package.perforce.com/).
* Pre-loads the [Perforce Sample Depot](http://answers.perforce.com/articles/KB/2439), making it instantly ready for training and evaluation purposes.
* Simplifies Enterprise Deployment.  While optimized for getting going quickly, the Helix Installer is designed to enable a fast path from a Proof of Concept (PoC) to small-scale production deployment following the Helix evaluation, with only a nominal hop from there to a large-scale global enterprise deployment (which requires custom configuration based on the specific global topology).

### Case Study: Sample Usage of Helix Installer in CBD Test Suite

The [Component Based Development (CBD)](https://swarm.workshop.perforce.com/projects/perforce-software-cbd) system, another project in The Workshop, uses this Helix Installer as part of its automated test suite.  In conjunction with Vagrant and Virtual Box, which build a vanilla VM from the ground up, the [CBD Test Suite](https://swarm.workshop.perforce.com/projects/perforce-software-cbd/files/main/test/auto_test_cbd_vagrant.sh) uses the Helix Installer to deploy a Perforce server, complete with Sample Depot test data set, plus Python and P4Python needed to test the CBD scripts.

### Case Study: Sample Usage of Helix Installer in Battle School Workshop

A slightly modified Helix Installer is a key component of the Battle School Workshop.  The Battle School Workshop Lab Engine quickly tears down and spins up a fresh, enterprise-style Helix installation -- and then breaks it in order to simulate real-world problems that students learn to identify and fix.  The Battle School version of the Helix Installer (not presently available for public consumption) uses a simulated global topology with replicas and edge servers.

### Instructions and Usage Example

The `reset_sdp.sh` script is the only script that should be downloaded.  It downloads everything it needs, including other scripts and files from this Helix Installer package, executables from the Perforce FTP site, and the SDP from The Workshop (acquired by cloning).

Once installing a vanilla CentOS 6.7 (or similar) machine, do this as root:

    useradd perforce
    mkdir -p /hxdepots/reset
    chown -R perforce:perforce /hxdepots/reset
    cd /hxdepots/reset
    curl -k -s -O https://swarm.workshop.perforce.com/downloads/guest/perforce_software/helix-installer/main/src/reset_sdp.sh

    chmod +x reset_sdp.sh

    ./reset_sdp.sh -man

    ./reset_sdp.sh 2>&1 | tee reset_sdp.log

A similar procedure works for Mac OSX, except that the standard Mac interface is used for creating the `perforce` user account rather than the `useradd` command, and the `chown` command may need to specify a different group (e.g. `staff`), depending on the Mac OSX environment.

## Helix Installer Release Notes

See the [Helix Installer Release Notes](https://swarm.workshop.perforce.com/projects/perforce_software-helix-installer/files/main/doc/ReleaseNotes.md).

## Helix Installer Roadmap

### Helix Installer 2016.1 (First formal release, available now)

Helix Installer 2016.1 is available today, and installs the following Helix Components, all fully configured an integrated:

* P4D 2016.1 - the Helix Versioning Engine, the core of Helix (with or without SSL enabled).
* P4Broker 2016.1 - the Helix Broker, enhances custom automation capabilities, simplifies maintenances.
* SDP 2016.1 - Server Deployment Package (For managing the SDP).
* Sample Depot data set for training, evaluation, and demo, and pilot projects.

### Helix Installer 2017.1 (ETA Q2 2017)

The 2017.1 release is expected to add support for:

* Helix Swarm - Collaborative web-based code review and continuous delivery.

### Helix Installer 2017.2 (ETA ???)

The 2017.2 release is expected to add support for:

* Helix Git Fusion - enables Git collaboration and access to the Helix Versioning Engine for Git users.

* Optimized for easy Git repo insertion.  A `p4import` user is created and configured with an SSH key, ready to immediately start Git repo imports.  A supplemental `higf_import` tool imports Git the master branch of a git repos in a single step, needing only the cloning URL as input.

## Platform Support

Helix Installer 2016.1 supports: 

* CentOS/RHEL 6.5 thru 7.3.
* Limited support for Mac OSX/Darwin

Future releases may add support for other popular Linux distributions, including those using APT, e.g. Ubuntu and Debian.  It may well work as-is presently on other YUM-based installations.

## Project Status

As of October 2017, this project is functional and has been actively used since April 2015.  It has been actively maintained to keep pace with SDP changes.  However, planned releases to add new features, auto-installing Swarm and Git Fusion support, have been deferred.

## Safety Warning
Note that this software ***SHOULD NEVER EXIST*** on a Production Perforce server.  The is intended to quickly tear down and rebuild a fresh Perforce server (e.g. for operating test suites).  It should not exist on a machine containing real Perforce data.

It may be useful for doing an initial installation, e.g. to a cloud hosted environment.  After the initial install, the reset_sdp.sh script should be removed.

## Contact Us

Please [contact Perforce Consulting Services] (mailto:consulting@perforce.com) for more information.

